import { renderless, api } from '@opentinyvue/vue-renderless/tag/vue';
import { defineComponent, props, setup, h } from '@opentinyvue/vue-common';
import { IconClose } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "dark-success": "text-color-text-inverse bg-color-success",
  "dark-alerting": "text-color-text-inverse bg-color-alert",
  "dark-warning": "text-color-text-inverse bg-color-warning",
  "dark-error": "text-color-text-inverse bg-color-error",
  "dark-default": "text-color-text-inverse bg-color-info-primary",
  "dark-info": "text-color-text-inverse bg-color-text-placeholder",
  "dark-pink": "text-color-text-inverse bg-color-chart-17",
  "dark-purple": "text-color-text-inverse bg-color-chart-11",
  "dark-cyan": "text-color-text-inverse bg-color-chart-2",
  "light-success": "text-color-success bg-color-success-subtler",
  "light-alerting": "text-color-alert bg-color-alert-subtler",
  "light-warning": "text-color-warning bg-color-warning-subtler",
  "light-error": "text-color-error bg-color-error-subtler",
  "light-default": "text-color-info-primary bg-color-info-primary-subtler",
  "light-info": "text-color-text-primary bg-color-bg-3",
  "light-pink": "text-color-chart-17 bg-color-chart-17-subtler",
  "light-purple": "text-color-chart-11 bg-color-chart-11-subtler",
  "light-cyan": "text-color-chart-2 bg-color-chart-2-subtler",
  "plain-success": "text-color-success bg-color-bg-1",
  "plain-alerting": "text-color-alert bg-color-bg-1",
  "plain-warning": "text-color-warning bg-color-bg-1",
  "plain-error": "text-color-error bg-color-bg-1",
  "plain-default": "text-color-info-primary bg-color-bg-1",
  "plain-info": "text-color-text-primary bg-color-bg-1",
  "plain-pink": "text-color-chart-17 bg-color-bg-1",
  "plain-purple": "text-color-chart-11 bg-color-bg-1",
  "plain-cyan": "text-color-chart-2 bg-color-bg-1",
  "success-border": "border-color-success-subtle",
  "alerting-border": "border-color-alert-subtle",
  "warning-border": "border-color-warning-subtle",
  "error-border": "border-color-error-subtle",
  "default-border": "border-color-info-primary-subtle",
  "info-border": "border-color-none",
  "pink-border": "border-color-chart-17-subtle",
  "purple-border": "border-color-chart-11-subtle",
  "cyan-border": "border-color-chart-2-subtle",
  "fill-dark": "fill-color-bg-6 hover:fill-color-icon-inverse",
  "fill-light-success": "fill-color-success-subtle hover:fill-color-success",
  "fill-light-alerting": "fill-color-alert-subtle hover:fill-color-alert",
  "fill-light-warning": "fill-color-warning-subtle hover:fill-color-warning",
  "fill-light-error": "fill-color-error-subtle hover:fill-color-error",
  "fill-light-default": "fill-color-info-primary-subtle hover:fill-color-info-primary",
  "fill-light-info": "fill-color-icon-secondary hover:fill-color-icon-secondary",
  "fill-light-pink": "fill-color-chart-17-subtle hover:fill-color-chart-17",
  "fill-light-purple": "fill-color-chart-11-subtle hover:fill-color-chart-11",
  "fill-light-cyan": "fill-color-chart-2-subtle hover:fill-color-chart-2",
  "selectable-unselect": "h-9 sm:h-7 text-color-text-primary bg-color-bg-4 cursor-pointer hover:bg-color-fill-1",
  "selectable-selected": "h-9 sm:h-7 text-color-brand border-current bg-color-info-primary-subtler cursor-pointer hover:text-color-brand-hover",
  "tag-disabled": "h-9 sm:h-7 text-color-text-disabled bg-color-bg-4 border-transparent cursor-not-allowed hover:text-color-text-disabled hover:bg-color-bg-4",
  "tag-operable": "h-7 sm:h-6 cursor-pointer",
  "medium": "h-7 px-3",
  "small": "h-6 px-2",
  "mini": "h-5 px-1"
};
var __vue2_script = defineComponent({
  components: {
    IconClose: IconClose()
  },
  emits: ["click", "close"],
  props: [].concat(props, ["text", "closable", "operable", "selectable", "type", "theme", "hit", "disabled", "color", "size", "effect", "customClass", "value", "maxWidth"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      h,
      classes
    });
  },
  render: function render() {
    var h2 = arguments[0];
    var slots = this.slots, selectable = this.selectable, disabled = this.disabled, color = this.color, handleClose = this.handleClose, handleClick = this.handleClick, customClass = this.customClass, hit = this.hit, m = this.m, gcls = this.gcls, state = this.state, value = this.value, maxWidth = this.maxWidth;
    var size = selectable ? "medium" : this.size || "small";
    var type = selectable ? "info" : state.type || "info";
    var effect = selectable ? "light" : this.effect || "light";
    var closable = selectable ? false : this.closable;
    var operable = selectable ? false : this.operable;
    var classes2 = m("text-xs inline-flex items-center rounded box-border border-0.5 sm:border mr-1", effect === "plain" || hit ? gcls(type + "-border") : "border-transparent", gcls(effect + "-" + type), gcls(size), {
      hidden: !state.show
    }, selectable ? state.selected ? gcls("selectable-selected") : gcls("selectable-unselect") : "", selectable && disabled ? gcls("tag-disabled") : "", operable ? gcls("tag-operable") : "", customClass);
    var styles = {
      backgroundColor: color
    };
    if (maxWidth) {
      styles.maxWidth = maxWidth;
      styles.display = "inline-block";
    }
    var tagElement = value || slots.default && slots.default() ? h2("span", {
      "attrs": {
        "data-tag": "tiny-tag"
      },
      "class": classes2,
      "style": styles,
      "on": {
        "click": handleClick
      }
    }, [value ? h2("span", [value]) : slots.default && slots.default(), closable && h2("icon-close", {
      "class": ["w-3 h-3 ml-1 cursor-pointer", effect === "dark" ? gcls("fill-dark") : gcls("fill-light-" + type)],
      "on": {
        "click": handleClose
      }
    })]) : h2("span");
    return tagElement;
  }
});
var __vue2_render, __vue2_staticRenderFns;
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, __vue2_render, __vue2_staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
